about summary refs log tree commit diff stats
path: root/046global.cc
diff options
context:
space:
mode:
authorKartik K. Agaram <vc@akkartik.com>2016-09-17 14:43:13 -0700
committerKartik K. Agaram <vc@akkartik.com>2016-09-17 14:43:13 -0700
commit0f2781f8a28881084295663c3e608e5f6f159047 (patch)
tree46d0d2df3cbd29c329a314ddf0f8b3a92e1d4d08 /046global.cc
parent59085fca6083a08f67911a35c02f012c19d7df48 (diff)
downloadmu-0f2781f8a28881084295663c3e608e5f6f159047.tar.gz
3393
Diffstat (limited to '046global.cc')
-rw-r--r--046global.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/046global.cc b/046global.cc
index 652d025f..39cc3a6b 100644
--- a/046global.cc
+++ b/046global.cc
@@ -11,10 +11,10 @@
 
 :(scenario global_space)
 def main [
   # pretend address:@:location; in practice we'll use new
   10:num <- copy 0  # refcount
   11:num <- copy 5  # length
   # pretend address:@:location; in practice we'll use new
   20:num <- copy 0  # refcount
   21:num <- copy 5  # length
   # actual start of this recipe
@@ -43,7 +43,7 @@ global_space = 0;
 :(after "Begin Preprocess write_memory(x, data)")
 if (x.name == "global-space") {
   if (!scalar(data) || !is_space(x))
-    raise << maybe(current_recipe_name()) << "'global-space' should be of type address:@:location, but tried to write '" << to_string(x.type) << "'\n" << end();
+    raise << maybe(current_recipe_name()) << "'global-space' should be of type address:array:location, but tried to write '" << to_string(x.type) << "'\n" << end();
   if (Current_routine->global_space)
     raise << "routine already has a global-space; you can't over-write your globals" << end();
   Current_routine->global_space = data.at(0);
@@ -11,10 +11,10 @@
 :(scenario global_space)
 def main [
-  # pretend address:@:location; in practice we'll use new
+  # pretend address:array:location; in practice we'll use new
   10:num <- copy 0  # refcount
   11:num <- copy 5  # length
@@ -11,10 +11,10 @@
   10:num <- copy 0  # refcount
   11:num <- copy 5  # length
-  # pretend address:@:location; in practice we'll use new
+  # pretend address:array:location; in practice we'll use new
   20:num <- copy 0  # refcount
   21:num <- copy 5  # length